@@ -2,9 +2,9 @@
 //                                                                         //
 //  PonyProg - Serial Device Programmer                                    //
 //                                                                         //
-//  Copyright (C) 1997-2021   Claudio Lanconelli                           //
+//  Copyright (C) 1997-2025   Claudio Lanconelli                           //
 //                                                                         //
-//  http://ponyprog.sourceforge.net                                        //
+//  https://github.com/lancos/ponyprog                                        //
 //                                                                         //
 //-------------------------------------------------------------------------//
 //                                                                         //
@@ -121,7 +121,7 @@ int MpsseInterface::InitPins()
 			return E2ERR_OPENFAILED;
 		}
 
-		qDebug() << Q_FUNC_INFO << (hex)
+		qDebug() << Q_FUNC_INFO << (Qt::hex)
 				 << " Ctrl=" << pin_ctrl
 				 << ", Clock=" << pin_clock << ", ClockIn=" << pin_clockin
 				 << ", DataIn=" << pin_datain << ", DataOut=" << pin_dataout
@@ -130,7 +130,7 @@ int MpsseInterface::InitPins()
 		result = ctx.set_bitmode(0, BITMODE_MPSSE);
 		if (result == 0)
 		{
-			ctx.flush();
+			ctx.tcflush();		//ctx.flush(); deprecated
 			cmdbuf.clear();
 
 			int new_data = 0;
@@ -218,7 +218,7 @@ int MpsseInterface::SetFrequency(uint32_t freq)
 
 int MpsseInterface::Open(int port)
 {
-	qDebug() << Q_FUNC_INFO << "(" << port << (hex) << usb_vp.vid << ":" << usb_vp.pid << ") IN";
+	qDebug() << Q_FUNC_INFO << "(" << port << (Qt::hex) << usb_vp.vid << ":" << usb_vp.pid << ") IN";
 
 	int ret_val = OK;
 
@@ -1171,40 +1171,7 @@ int MpsseInterface::TestPort(int port_no)
 			else
 			{
 				//PonyProgFT
-				w.WaitMsec(10);
-				ret_val = GetPresence(0x0700, 0);
-
-				if (ret_val == OK)
-				{
-					SendPins(OutDataMask(pin_enbus, 1));	//en_bus active low
-					SendPins(OutDataMask(pin_ctrl | pin_dataout | pin_clock, 0));
-					SetPower(true);
-					w.WaitMsec(150);
-					int val = GetPins();
-					if (val < 0 || GetCtrlIn(val) != 1)
-					{
-						if (GetDataIn(val) != 1)
-						{
-							ret_val = E2ERR_IOTEST;
-						}
-						else
-						{
-							ret_val = E2ERR_NOTINSTALLED;
-						}
-					}
-					else
-					{
-						SendPins(OutDataMask(pin_ctrl, 1));
-						w.WaitMsec(100);
-						val = GetPins();
-						if (val < 0 || GetCtrlIn(val) != 0)
-						{
-							ret_val = E2ERR_NOTINSTALLED;
-						}
-					}
-					SendPins(OutDataMask(pin_ctrl | pin_dataout | pin_clock, 0));
-					SetPower(false);
-				}
+				TestPonyProgFTStandalone();
 			}
 		}
 		else if (TypeToInterfVidPid(FTDI_JTAGKEY) == usb_vp)
@@ -1212,6 +1179,11 @@ int MpsseInterface::TestPort(int port_no)
 			//JtagKey
 			ret_val = OK;
 		}
+		else if (TypeToInterfVidPid(EGGLINK_V3) == usb_vp)
+		{
+			//EGGLINK V3
+			TestPonyProgFTStandalone();
+		}
 		else
 		{
 			ret_val = E2ERR_NOTINSTALLED;
@@ -1224,3 +1196,45 @@ int MpsseInterface::TestPort(int port_no)
 
 	return ret_val;
 }
+
+int MpsseInterface::TestPonyProgFTStandalone()
+{
+	int ret_val;
+
+	w.WaitMsec(10);
+	ret_val = GetPresence(0x0700, 0);
+
+	if (ret_val == OK)
+	{
+		SendPins(OutDataMask(pin_enbus, 1));	//en_bus active low
+		SendPins(OutDataMask(pin_ctrl | pin_dataout | pin_clock, 0));
+		SetPower(true);
+		w.WaitMsec(150);
+		int val = GetPins();
+		if (val < 0 || GetCtrlIn(val) != 1)
+		{
+			if (GetDataIn(val) != 1)
+			{
+				ret_val = E2ERR_IOTEST;
+			}
+			else
+			{
+				ret_val = E2ERR_NOTINSTALLED;
+			}
+		}
+		else
+		{
+			SendPins(OutDataMask(pin_ctrl, 1));
+			w.WaitMsec(100);
+			val = GetPins();
+			if (val < 0 || GetCtrlIn(val) != 0)
+			{
+				ret_val = E2ERR_NOTINSTALLED;
+			}
+		}
+		SendPins(OutDataMask(pin_ctrl | pin_dataout | pin_clock, 0));
+		SetPower(false);
+	}
+
+	return ret_val;
+}
